#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add calibration resubmit script

Revision ID: e47383255e83
Revises: b45789abd24a
Create Date: 2021-10-28 15:05:12.627521

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "e47383255e83"
down_revision = "b45789abd24a"
branch_labels = None
depends_on = None


content = b"""#!/usr/bin/env bash

set -o errexit -o nounset

# This script is for resubmitting a manually altered standard calibration.
# A new capability request version will be created and all relevant files
# from the previous version results (contained in the current directory) will be appended to it.

CAPABILITY_SERVICE=$(capo -q edu.nrao.workspaces.CapabilitySettings.serviceUrl)

# create new request version
data_location={{spool_dir}}/rawdata
if [[ -L $data_location ]]; then
    qa="qa2"
    corrected_location="${data_location/spool/"$qa"}"
    params="{\\"resubmit\\": true, \\"rawdata_dir\\":\\"location\\"}"
    corrected_params="${params/location/"$corrected_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
else
    params="{\\"resubmit\\": true, \\"rawdata_dir\\":\\"location\\"}"
    corrected_params="${params/location/"$data_location"}"
    capability_request_id=$(curl --header "Content-Type: application/json" --request POST --data "$corrected_params" $CAPABILITY_SERVICE/capability/request/execution/{{request_id}}/create_version)
fi
# add all files in current directory to new version

# sort files for valid additions
echo "Sorting files...."
mkdir "system_logs"
mv *.{err,out,log,dag,condor} ./system_logs
mv std_calibration* ./system_logs
echo "Files sorted. Continuing...."

for appendFile in $PWD/*; do
  if [[ -f "${appendFile}" ]] && [[ "${appendFile##*/}" != "resubmit.sh" ]] && [[ "${appendFile##*/}" != "metadata.json" ]]; then
    echo "Found a file to add..."
    filename="${appendFile##*/}"
    curl -X PUT --data-binary "@$appendFile" $CAPABILITY_SERVICE/capability/request/$capability_request_id/version/latest/files/$filename
  fi
done
echo "All files added."

# submit new version for execution
curl -X POST $CAPABILITY_SERVICE/capability/request/$capability_request_id/submit


"""


def upgrade():
    op.get_bind().execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('resubmit.sh', %s, 'std_calibration')
        """,
        content,
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='resubmit.sh' AND workflow_name='std_calibration'
        """
    )
